# Jupyter Community Call

## May 28th, 2019

**Date:** 28 May 2019 at 9am PST (your [timezome](http://arewemeetingyet.com/Los%20Angeles/2019-05-28/09:00/Jupyter%20Community%20Call))

**Link:** [Youtube Video](https://youtu.be/mqZCa8j2K4s)


## Welcome to the All-Jupyter Community Meeting

## Purpose

The purpose of these monthly video conference calls is to share and demonstrate the awesome things happening in Jupyter community. We invite **anyone** to present their work, engage in discussion, or just sit in and listen. Whether you have a new [lab extension](https://github.com/jupyterlab) you've created, a new [jupyterhub deployment](https://github.com/jupyterhub) you're excited about, or an [nteract papermill](https://github.com/nteract) pipeline powering your business, we'd love to hear about it! And, we'll  record and publish these calls on YouTube for anyone unable to attend.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

This is a place to make *short* announcements (without a need for discussion). This is also a great place to give shout-outs to contributors! We’ll read through these at the beginning of the meeting.

* Hello from [The Turing Way](https://github.com/alan-turing-institute/the-turing-way) Book Dash :books::dash::dash: in London. This call is right at the end of a day of 18 people working together to improve the openly developed [Jupyter book](https://github.com/jupyter/jupyter-book/). Our goal is to make "Reproducibility too easy not to do" (:laughing::grimacing::scream_cat:), build a strong and supportive community, and give people the knowledge and confidence they need to contribute to open source projects  [name=Kirstie & Turing Way team]
  * GitHub repo: https://github.com/alan-turing-institute/the-turing-way
  * The book: https://the-turing-way.netlify.com
  * Chat room: https://gitter.im/alan-turing-institute/the-turing-way


## Agenda Items

Add your potential agenda item here **24 hours before** the meeting at the latest. We will reorganize the agenda so that it fits in the 60m meeting slot.

* Feedback and report from Research Software Reactor Sprint [name=Sarah] 
  * Event website: https://www.microsoftevents.com/profile/form/index.cfm?PKformID=0x6927743abcd
  * Project list: https://github.com/research-software-reactor
  * New binderhub in the world :baby: :confetti_ball: https://twitter.com/gerardjgorman/status/1131097133292183553
* Feedback and report from Jupyter Server Design and Roadmap workshop [name=Luciano]
    * sponsored by bloomberg
    * thomas, kevin, etc.
    * functionality directions, high-level roadmap
    * decouple frontend from backend: notebook, lab, nteract, voila
    * using the backend functionality, providing different UIs
    * how do we accomplish that? jupyter_server extension points
        - ui
        - backend
        - handlers
    * roadmap
        * phase 1: integrating with existing uis (notebookclassic, lab)
        * phase 2: expand functionality
            * kernel provider pr (e.g. different kernel managers, like Enterprise Kernel Gateway)
        * next steps: 
            * pr from zak
            * blog post (illustration)
            * biweekly calls
        * timeline:
            * 6.0 release of notebook?
            * post jupyterlab 1.0?
* Qt(5.6)-based PDF output from JupyterLab (0.35) 
  Quick demo of using QtWebEngine to load a notebook in lab and make a PDF. $_{n+1}$th time's the charm! [![Launch Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/deathbeds/nbconvert-pdfqt/master?urlpath=lab%2Ftree%2Fnotebooks%2Findex.ipynb) | [issue](https://github.com/jupyter/nbconvert/issues/1031) | [repo](https://github.com/deathbeds/nbconvert-pdfqt) | [name=Nick]

## Attendees

If you are joining the All-Jupyter Community video meeting, sign in below so we know who was here. Roll call:

- | Zach    | Jupyter Cal Poly          | @Zsailer        |
- | Amit    | ReviewNB                  | @amit1rrr       |
- | Kirstie | Alan Turing Institute     | @KirstieJane    |
- | Pete    | Thorn                     | @parente        |
- | Tony    | Quansight                 | @tonyfast       |
- | Nick    | GTRI                      | @bollwyvl       |
- | Luciano | IBM                       | @lresende       |
- | Sarah   | The Alan Turing Institute | @sgibson91      |
- | Saul    | Quansight                 | @saulshanabrook |
- | James   | MUN                       | @jmunroe        |
- | Darian  | Two Sigma                 | @afshin         |
- | Matthias| UC Merced                 | @carreau        |
- | Tania   | Microsoft                 | @trallard       |
- | Carol   | Project Jupyter           | @willingc       |
- | Chris   | UNC-Chapel Hill           | @cbcunc         |